declare module 'archiver' {
  const value: any
  export default value
}

declare module 'handlebars' {
  const value: any
  export default value
}

declare module 'karma' {
  export const Server: any
}

declare module 'rollup' {
  export type OutputOptions = any
  export type Plugin = any
  export type RollupOptions = any
  export type RollupWarning = any
  export const rollup: any
  export const watch: any
}

declare module 'rollup-plugin-dts' {
  const value: any
  export default value
}

declare module 'rollup-plugin-postcss' {
  const value: any
  export default value
}
declare module 'postcss-comment' {
  const value: any
  export default value
}

declare module 'rollup-plugin-sourcemaps' {
  const value: any
  export default value
}

declare module '@rollup/plugin-commonjs' {
  const value: any
  export default value
}

declare module '@rollup/plugin-json' {
  const value: any
  export default value
}

declare module '@rollup/plugin-node-resolve' {
  const value: any
  export default value
}

declare module '@rollup/plugin-replace' {
  const value: any
  export default value
}
